Quantcast

optimize settings

Ou Junhui [06-17-21 - 15:58]
optimize settings
Filename
oUF/oUF.toc
oUF_SimpleConfig/nameplate.lua
rButtonTemplate_Zork/theme.lua
rChat/core.lua
rFilter_Zork/classes/hunter.lua
rMinimap/core.lua
diff --git a/oUF/oUF.toc b/oUF/oUF.toc
index 0762bce..98bdb7a 100644
--- a/oUF/oUF.toc
+++ b/oUF/oUF.toc
@@ -1,4 +1,4 @@
-## Interface: 90002
+## Interface: 20501
 ## Title: oUF |cff1a9fc0BCC|r
 ## Author: Haste, lightspark, p3lim, Rainrider
 ## Version: @project-version@
diff --git a/oUF_SimpleConfig/nameplate.lua b/oUF_SimpleConfig/nameplate.lua
index 32171bb..59e35df 100644
--- a/oUF_SimpleConfig/nameplate.lua
+++ b/oUF_SimpleConfig/nameplate.lua
@@ -37,7 +37,8 @@ local cvars = {
   nameplateMaxAlpha         = 0.5,
   nameplateMinAlphaDistance = 0,
   nameplateMaxAlphaDistance = 41,
-  nameplateSelectedAlpha    = 1
+  nameplateSelectedAlpha    = 1,
+  nameplateMaxDistance      = 41,
 }

 L.C.NamePlateCVars = cvars
diff --git a/rButtonTemplate_Zork/theme.lua b/rButtonTemplate_Zork/theme.lua
index 1cf1c43..cfcddc1 100644
--- a/rButtonTemplate_Zork/theme.lua
+++ b/rButtonTemplate_Zork/theme.lua
@@ -212,3 +212,21 @@ debuffButtonConfig.duration.font = { fontExpressway, 12.5, "OUTLINE"}

 --rButtonTemplate:StyleDebuffButtons
 rButtonTemplate:StyleDebuffButtons(debuffButtonConfig)
+
+-----------------------------
+-- bagButtonConfig
+-----------------------------
+
+local bagButtonConfig = copyTable(auraButtonConfig)
+--change the backdrop a bit
+bagButtonConfig.backdrop.bgFile = "Interface\\Buttons\\WHITE8x8"
+bagButtonConfig.backdrop.edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border"
+bagButtonConfig.backdrop.tileSize = 16
+bagButtonConfig.backdrop.edgeSize = 16
+bagButtonConfig.backdrop.insets = {left=3,right=3,top=3,bottom=3}
+bagButtonConfig.backdrop.backgroundColor = {0.08,0.08,0.1,0.92}
+bagButtonConfig.backdrop.borderColor = {0.1,0.1,0.1,0.6}
+
+--rButtonTemplate:StyleAllSlotButtons
+-- rButtonTemplate:StyleAllSlotButtons(bagButtonConfig)
+rButtonTemplate_Zork_SlotButtonConfig = bagButtonConfig
\ No newline at end of file
diff --git a/rChat/core.lua b/rChat/core.lua
index 3904532..1c55955 100644
--- a/rChat/core.lua
+++ b/rChat/core.lua
@@ -148,7 +148,7 @@ ChatFontNormal:SetShadowOffset(unpack(cfg.dropshadow.offset))
 ChatFontNormal:SetShadowColor(unpack(cfg.dropshadow.color))

 --font size
-CHAT_FONT_HEIGHTS = {10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20}
+CHAT_FONT_HEIGHTS = {12, 14, 16, 17, 18, 19, 20}

 --tabs
 CHAT_TAB_HIDE_DELAY = 1
diff --git a/rMinimap/core.lua b/rMinimap/core.lua
index 040a0d6..00813b9 100644
--- a/rMinimap/core.lua
+++ b/rMinimap/core.lua
@@ -80,14 +80,15 @@ QueueStatusMinimapButton:SetPushedTexture(nil)

 --mail
 MiniMapMailFrame:ClearAllPoints()
-MiniMapMailFrame:SetPoint("BOTTOMRIGHT",Minimap,-0,0)
+MiniMapMailFrame:SetPoint("BOTTOMRIGHT",Minimap,-5,5)
 MiniMapMailIcon:SetTexture(mediapath.."mail")
-MiniMapMailBorder:SetTexture("Interface\\Calendar\\EventNotificationGlow")
-MiniMapMailBorder:SetBlendMode("ADD")
-MiniMapMailBorder:ClearAllPoints()
-MiniMapMailBorder:SetPoint("CENTER",MiniMapMailFrame,0.5,1.5)
-MiniMapMailBorder:SetSize(27,27)
-MiniMapMailBorder:SetAlpha(0.5)
+MiniMapMailBorder:Hide()
+-- MiniMapMailBorder:SetTexture("Interface\\Calendar\\EventNotificationGlow")
+-- MiniMapMailBorder:SetBlendMode("ADD")
+-- MiniMapMailBorder:ClearAllPoints()
+-- MiniMapMailBorder:SetPoint("CENTER",MiniMapMailFrame,0.5,1.5)
+-- MiniMapMailBorder:SetSize(27,27)
+-- MiniMapMailBorder:SetAlpha(0.5)

 --MiniMapTracking
 MiniMapTracking:SetParent(Minimap)
diff --git a/rFilter_Zork/classes/hunter.lua b/rFilter_Zork/classes/hunter.lua
index e03700d..84c99ee 100644
--- a/rFilter_Zork/classes/hunter.lua
+++ b/rFilter_Zork/classes/hunter.lua
@@ -24,41 +24,41 @@ local A, L = ...
 -- spec with ur own
 ----------------------------
 if L.C.playerClass == "HUNTER" then
-  -- 毒蛇钉刺, row 1 col 1
-  rFilter:CreateDebuff(13550,"target",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",8,0},"show",{0,1},true,"player")
-  -- rFilter:CreateCooldown(185313,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",8,0},"[combat]show;hide",{0.2,1},true)
-  -- 切割, row 1 col 2
-  -- rFilter:CreateBuff(315496,"player",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",50,0},"show",{0,1},true,nil)
-  -- rFilter:CreateCooldown(315496,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",50,0},"[combat]show;hide",{1,1},true)
-  -- 割裂, row 1 col 3
-  -- rFilter:CreateDebuff(1943,"target",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",92,0},"show",{0,1},true,"player")
-  -- rFilter:CreateCooldown(3,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",92,0},"show",{1,1},true)
+  -- 杀戮命令, row 1 col 1
+  -- rFilter:CreateDebuff(13554,"target",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",8,0},"show",{0,1},true,"player")
+  rFilter:CreateCooldown(34026,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",8,0},"[combat]show;hide",{0.2,1},true)
+  -- 急速射击, row 1 col 2
+  rFilter:CreateBuff(3045,"player",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",50,0},"show",{0,1},true,nil)
+  rFilter:CreateCooldown(3045,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",50,0},"[combat]show;hide",{0.2,1},true)
+  -- 冰冻陷阱, row 1 col 3
+  rFilter:CreateDebuff(14309,"target",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",92,0},"show",{0,1},true,nil)
+  rFilter:CreateCooldown(14311,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",92,0},"[combat]show;hide",{0.2,1},true)
   -- 震荡射击, row 1 col 4
-  rFilter:CreateDebuff(5116,"target",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",134,0},"show",{0,1},true,"player")
+  rFilter:CreateDebuff(5116,"target",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",134,0},"show",{0,1},true,nil)
   rFilter:CreateCooldown(5116,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",134,0},"[combat]show;hide",{0.2,1},true)
   -- 奥射, row 1 col 5 315496 212283
   -- rFilter:CreateBuff(212283,"player",36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",176,0},"show",{0,1},true,nil)
-  rFilter:CreateCooldown(14282,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",176,0},"[combat]show;hide",{0.2,1},true)
+  rFilter:CreateCooldown(14286,36,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",176,0},"[combat]show;hide",{0.2,1},true)

-  -- 法力风流, row 2 col 1
+  -- 法力分流, row 2 col 1
   rFilter:CreateBuff(28734,"player",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",8,-42},"show",{0,1},true,nil)
   rFilter:CreateCooldown(28734,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",8,-42},"[combat]show;hide",{0.2,1},true)
   -- 法力洪流, row 2 col 2
   rFilter:CreateDebuff(28730,"target",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",38,-42},"show",{0,1},true,nil)
   rFilter:CreateCooldown(28730,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",38,-42},"[combat]show;hide",{0.2,1},true)
-  -- 血瓶, row 2 col 3
-  -- rFilter:CreateBuff(185311,"player",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",68,-42},"show",{0,1},true,nil)
-  -- rFilter:CreateCooldown(185311,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",68,-42},"[combat]show;hide",{0.2,1},true)
-  -- 暗影步, row 2 col 4
-  -- rFilter:CreateBuff(36554,"player",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",98,-42},"show",{0,1},true,nil)
-  -- rFilter:CreateCooldown(36554,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",98,-42},"[combat]show;hide",{0.2,1},true)
-  -- 疾跑, row 2 col 5
-  -- rFilter:CreateBuff(2983,"player",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",128,-42},"show",{0,1},true,nil)
-  -- rFilter:CreateCooldown(2983,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",128,-42},"[combat]show;hide",{0.2,1},true)
-  -- 嫁祸, row 2 col 6
-  -- rFilter:CreateBuff(11,"player",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",158,-42},"show",{0.2,1},true,nil)
-  -- rFilter:CreateCooldown(57934,24,{"TOPLEFT",oUF_SimplePlayer, "TOPRIGHT",158,-42},"[combat]show;hide",{0.2,1},true)
-  -- 震荡射击, row 2 col 7
-  -- rFilter:CreateDebuff(5116,"target",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",188,-42},"show",{0,1},true,nil)
-  -- rFilter:CreateCooldown(5116,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",188,-42},"[combat]show;hide",{0.2,1},true)
+  -- 假死, row 2 col 3
+  rFilter:CreateBuff(5384,"player",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",68,-42},"show",{0,1},true,nil)
+  rFilter:CreateCooldown(5384,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",68,-42},"[combat]show;hide",{0.2,1},true)
+  -- 狂野, row 2 col 4
+  rFilter:CreateBuff(34471,"player",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",98,-42},"show",{0,1},true,nil)
+  rFilter:CreateCooldown(19574,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",98,-42},"[combat]show;hide",{0.2,1},true)
+  -- 毒蛇钉刺, row 2 col 5
+  rFilter:CreateDebuff(13554,"target",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",128,-42},"show",{0,1},true,"player")
+  -- rFilter:CreateCooldown(13554,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",128,-42},"[combat]show;hide",{0.2,1},true)
+  -- 瞄准射击, row 2 col 6
+  rFilter:CreateDebuff(20904,"target",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",158,-42},"show",{0,1},true,"player")
+  rFilter:CreateCooldown(20904,24,{"TOPLEFT",oUF_SimplePlayer, "TOPRIGHT",158,-42},"[combat]show;hide",{0.2,1},true)
+  -- 胁迫, row 2 col 7
+  rFilter:CreateDebuff(19577,"target",24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",188,-42},"show",{0,1},true,nil)
+  rFilter:CreateCooldown(19577,24,{"TOPLEFT",oUF_SimplePlayer,"TOPRIGHT",188,-42},"[combat]show;hide",{0.2,1},true)
 end